getenclosures
=============

Gets all enclosure urls from an RSS feed and pipes them to stdout

Usage
-----

::

    usage: getenclosures [-h] [--config-dir CONFIG_DIR] [--cache-dir CACHE_DIR]

    optional arguments:
      -h, --help            show this help message and exit
      --config-dir CONFIG_DIR
                Set config directory. Defaults to
                /Users/steven/Library/Application
                Support/getenclosures
      --cache-dir CACHE_DIR
                Set cache directory. Defaults to
                /Users/steven/Library/Caches/getenclosures

Installation
------------

Via ``pip``:

::

    pip3 install getenclosures

Alternatively:

-  Clone the repository, ``cd getenclosures``
-  Run ``python3 setup.py install`` or ``pip3 install -e``
